<?php

// ZoneMinder Brazilian Portuguese Traduction  By Victor Diago
//
// Feel Free to contact Me at illuminati@linuxmail.org
//
// Traduo Para Portugus do Brasil do Zoneminder
//
// Sinta-se Livre para me contactar em illuminati@linuxmail.org 


// Simple String Replacements
$zmSlang24BitColour          = 'cor 24 bits';
$zmSlang8BitGrey             = 'cinza 8 bits';
$zmSlangAction               = 'Action';
$zmSlangActual               = 'Atual';
$zmSlangAddNewControl        = 'Add New Control';
$zmSlangAddNewMonitor        = 'Adicionar Monitor';
$zmSlangAddNewUser           = 'Adicionar Usurio';
$zmSlangAddNewZone           = 'Adicionar Zona';
$zmSlangAlarm                = 'Alarme';
$zmSlangAlarmBrFrames        = 'Imagens<br/>Alarmadas';
$zmSlangAlarmFrameCount      = 'Alarm Frame Count';
$zmSlangAlarmFrame           = 'Imagem Alarmada';
$zmSlangAlarmLimits          = 'Limites de Alarme';
$zmSlangAlarmMaximumFPS      = 'Alarm Maximum FPS';
$zmSlangAlarmPx              = 'Pixel de Alarme';
$zmSlangAlarmRGBUnset        = 'You must set an alarm RGB colour';
$zmSlangAlert                = 'Alerta';
$zmSlangAll                  = 'Tudo';
$zmSlangApply                = 'Aplicar';
$zmSlangApplyingStateChange  = 'Aplicando mudana de estado';
$zmSlangArchArchived         = 'Somente Arquivados';
$zmSlangArchive              = 'Arquivar';
$zmSlangArchived             = 'Archived';
$zmSlangArchUnarchived       = 'Somente Nao Arquivados';
$zmSlangArea                 = 'Area';
$zmSlangAreaUnits            = 'Area (px/%)';
$zmSlangAttrAlarmFrames      = 'Imagens Alarmadas';
$zmSlangAttrArchiveStatus    = 'Status/Arquivamento';
$zmSlangAttrAvgScore         = 'Maior Score';
$zmSlangAttrCause            = 'Cause';
$zmSlangAttrDate             = 'Data';
$zmSlangAttrDateTime         = 'Data/Horario';
$zmSlangAttrDiskBlocks       = 'Blocos de Disco';
$zmSlangAttrDiskPercent      = 'Porcentagem de Disco';
$zmSlangAttrDuration         = 'Durao';
$zmSlangAttrFrames           = 'Imagens';
$zmSlangAttrId               = 'Id';
$zmSlangAttrMaxScore         = 'Max. Score';
$zmSlangAttrMonitorId        = 'Id do Monitor';
$zmSlangAttrMonitorName      = 'Nome do Monitor';
$zmSlangAttrName             = 'Nome';
$zmSlangAttrNotes            = 'Notes';
$zmSlangAttrSystemLoad       = 'System Load';
$zmSlangAttrTime             = 'Horrio';
$zmSlangAttrTotalScore       = 'Score Total';
$zmSlangAttrWeekday          = 'Dia/Semana';
$zmSlangAuto                 = 'Auto';
$zmSlangAutoStopTimeout      = 'Auto Stop Timeout';
$zmSlangAvgBrScore           = 'Maior<br/>Score';
$zmSlangBackground           = 'Background';
$zmSlangBackgroundFilter     = 'Run filter in background';
$zmSlangBadAlarmFrameCount   = 'Alarm frame count must be an integer of one or more';
$zmSlangBadAlarmMaxFPS       = 'Alarm Maximum FPS must be a positive integer or floating point value';
$zmSlangBadChannel           = 'Channel must be set to an integer of zero or more';
$zmSlangBadDevice            = 'Device must be set to a valid value';
$zmSlangBadFormat            = 'Format must be set to an integer of zero or more';
$zmSlangBadFPSReportInterval = 'FPS report interval buffer count must be an integer of 100 or more';
$zmSlangBadFrameSkip         = 'Frame skip count must be an integer of zero or more';
$zmSlangBadHeight            = 'Height must be set to a valid value';
$zmSlangBadHost              = 'Host must be set to a valid ip address or hostname, do not include http://';
$zmSlangBadImageBufferCount  = 'Image buffer size must be an integer of 10 or more';
$zmSlangBadLabelX            = 'Label X co-ordinate must be set to an integer of zero or more';
$zmSlangBadLabelY            = 'Label Y co-ordinate must be set to an integer of zero or more';
$zmSlangBadMaxFPS            = 'Maximum FPS must be a positive integer or floating point value';
$zmSlangBadNameChars         = 'Nomes devem ser caracteres alfanumricos mais hfen e underscore';
$zmSlangBadPath              = 'Path must be set to a valid value';
$zmSlangBadPort              = 'Port must be set to a valid number';
$zmSlangBadPostEventCount    = 'Post event image count must be an integer of zero or more';
$zmSlangBadPreEventCount     = 'Pre event image count must be at least zero, and less than image buffer size';
$zmSlangBadRefBlendPerc      = 'Reference blend percentage must be a positive integer';
$zmSlangBadSectionLength     = 'Section length must be an integer of 30 or more';
$zmSlangBadSignalCheckColour = 'Signal check colour must be a valid RGB colour string';
$zmSlangBadStreamReplayBuffer= 'Stream replay buffer must be an integer of zero or more';
$zmSlangBadWarmupCount       = 'Warmup frames must be an integer of zero or more';
$zmSlangBadWebColour         = 'Web colour must be a valid web colour string';
$zmSlangBadWidth             = 'Width must be set to a valid value';
$zmSlangBandwidth            = 'Larg/Banda';
$zmSlangBlobPx               = 'Px Blob';
$zmSlangBlobs                = 'Blobs';
$zmSlangBlobSizes            = 'Tam Blob';
$zmSlangBrightness           = 'Brilho';
$zmSlangBuffers              = 'Buffers';
$zmSlangCanAutoFocus         = 'Can Auto Focus';
$zmSlangCanAutoGain          = 'Can Auto Gain';
$zmSlangCanAutoIris          = 'Can Auto Iris';
$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
$zmSlangCanAutoZoom          = 'Can Auto Zoom';
$zmSlangCancel               = 'Cancelar';
$zmSlangCancelForcedAlarm    = 'Cancelar Alarme Forado';
$zmSlangCanFocusAbs          = 'Can Focus Absolute';
$zmSlangCanFocus             = 'Can Focus';
$zmSlangCanFocusCon          = 'Can Focus Continuous';
$zmSlangCanFocusRel          = 'Can Focus Relative';
$zmSlangCanGainAbs           = 'Can Gain Absolute';
$zmSlangCanGain              = 'Can Gain ';
$zmSlangCanGainCon           = 'Can Gain Continuous';
$zmSlangCanGainRel           = 'Can Gain Relative';
$zmSlangCanIrisAbs           = 'Can Iris Absolute';
$zmSlangCanIris              = 'Can Iris';
$zmSlangCanIrisCon           = 'Can Iris Continuous';
$zmSlangCanIrisRel           = 'Can Iris Relative';
$zmSlangCanMoveAbs           = 'Can Move Absolute';
$zmSlangCanMove              = 'Can Move';
$zmSlangCanMoveCon           = 'Can Move Continuous';
$zmSlangCanMoveDiag          = 'Can Move Diagonally';
$zmSlangCanMoveMap           = 'Can Move Mapped';
$zmSlangCanMoveRel           = 'Can Move Relative';
$zmSlangCanPan               = 'Can Pan' ;
$zmSlangCanReset             = 'Can Reset';
$zmSlangCanSetPresets        = 'Can Set Presets';
$zmSlangCanSleep             = 'Can Sleep';
$zmSlangCanTilt              = 'Can Tilt';
$zmSlangCanWake              = 'Can Wake';
$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
$zmSlangCanWhiteBal          = 'Can White Bal.';
$zmSlangCanWhite             = 'Can White Balance';
$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
$zmSlangCanZoom              = 'Can Zoom';
$zmSlangCanZoomCon           = 'Can Zoom Continuous';
$zmSlangCanZoomRel           = 'Can Zoom Relative';
$zmSlangCaptureHeight        = 'Altura da Captura';
$zmSlangCapturePalette       = 'Paleta de Captura';
$zmSlangCaptureWidth         = 'Largura de Captura';
$zmSlangCause                = 'Cause';
$zmSlangCheckMethod          = 'Metodo marcar por alarme';
$zmSlangChooseFilter         = 'Escolher Filtro';
$zmSlangChoosePreset         = 'Choose Preset';
$zmSlangClose                = 'Fechar';
$zmSlangColour               = 'Cor';
$zmSlangCommand              = 'Command';
$zmSlangConfig               = 'Config';
$zmSlangConfiguredFor        = 'Configurado para';
$zmSlangConfirmDeleteEvents  = 'Are you sure you wish to delete the selected events?';
$zmSlangConfirmPassword      = 'Confirmar Senha';
$zmSlangConjAnd              = 'E';
$zmSlangConjOr               = 'OU';
$zmSlangConsole              = 'Console';
$zmSlangContactAdmin         = 'Por favor contate o administrador para detalhes.';
$zmSlangContinue             = 'Continue';
$zmSlangContrast             = 'Contraste';
$zmSlangControlAddress       = 'Control Address';
$zmSlangControlCap           = 'Control Capability';
$zmSlangControlCaps          = 'Control Capabilities';
$zmSlangControl              = 'Control';
$zmSlangControlDevice        = 'Control Device';
$zmSlangControllable         = 'Controllable';
$zmSlangControlType          = 'Control Type';
$zmSlangCycle                = 'Cycle';
$zmSlangCycleWatch           = 'Ciclo Monitor';
$zmSlangDay                  = 'Dia';
$zmSlangDebug                = 'Debug';
$zmSlangDefaultRate          = 'Default Rate';
$zmSlangDefaultScale         = 'Default Scale';
$zmSlangDefaultView          = 'Default View';
$zmSlangDeleteAndNext        = 'Deletar &amp; Prx';
$zmSlangDeleteAndPrev        = 'Deletar &amp; Ant';
$zmSlangDelete               = 'Deletar';
$zmSlangDeleteSavedFilter    = 'Deletar Filtros Salvos';
$zmSlangDescription          = 'Descrio';
$zmSlangDeviceChannel        = 'Canal do Dispositivo';
$zmSlangDeviceFormat         = 'Formato do Dispos.';
$zmSlangDeviceNumber         = 'Num. do Dispos.';
$zmSlangDevicePath           = 'Device Path';
$zmSlangDevices              = 'Devices';
$zmSlangDimensions           = 'Dimenses';
$zmSlangDisableAlarms        = 'Disable Alarms';
$zmSlangDisk                 = 'Disco';
$zmSlangDonateAlready        = 'No, I\'ve already donated';
$zmSlangDonateEnticement     = 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.';
$zmSlangDonate               = 'Please Donate';
$zmSlangDonateRemindDay      = 'Not yet, remind again in 1 day';
$zmSlangDonateRemindHour     = 'Not yet, remind again in 1 hour';
$zmSlangDonateRemindMonth    = 'Not yet, remind again in 1 month';
$zmSlangDonateRemindNever    = 'No, I don\'t want to donate, never remind';
$zmSlangDonateRemindWeek     = 'Not yet, remind again in 1 week';
$zmSlangDonateYes            = 'Yes, I\'d like to donate now';
$zmSlangDownload             = 'Download';
$zmSlangDuration             = 'Durao';
$zmSlangEdit                 = 'Editar';
$zmSlangEmail                = 'Email';
$zmSlangEnableAlarms         = 'Enable Alarms';
$zmSlangEnabled              = 'Habilitado';
$zmSlangEnterNewFilterName   = 'Digite nome do novo filtro';
$zmSlangErrorBrackets        = 'Por favor cheque se voc tem o mesmo numero de chaves abertas e fechadas';
$zmSlangError                = 'Erro';
$zmSlangErrorValidValue      = 'Erro, por favor cheque se os campos esto corretos';
$zmSlangEtc                  = 'etc';
$zmSlangEvent                = 'Evento';
$zmSlangEventFilter          = 'Filtro de Evento';
$zmSlangEventId              = 'Id do Evento';
$zmSlangEventName            = 'Event Name';
$zmSlangEventPrefix          = 'Event Prefix';
$zmSlangEvents               = 'Eventos';
$zmSlangExclude              = 'Excluir';
$zmSlangExecute              = 'Execute';
$zmSlangExportDetails        = 'Export Event Details';
$zmSlangExport               = 'Export';
$zmSlangExportFailed         = 'Export Failed';
$zmSlangExportFormat         = 'Export File Format';
$zmSlangExportFormatTar      = 'Tar';
$zmSlangExportFormatZip      = 'Zip';
$zmSlangExportFrames         = 'Export Frame Details';
$zmSlangExportImageFiles     = 'Export Image Files';
$zmSlangExporting            = 'Exporting';
$zmSlangExportMiscFiles      = 'Export Other Files (if present)';
$zmSlangExportOptions        = 'Export Options';
$zmSlangExportVideoFiles     = 'Export Video Files (if present)';
$zmSlangFar                  = 'Far';
$zmSlangFastForward          = 'Fast Forward';
$zmSlangFeed                 = 'Alimentar';
$zmSlangFileColours          = 'File Colours';
$zmSlangFile                 = 'File';
$zmSlangFilePath             = 'File Path';
$zmSlangFilterArchiveEvents  = 'Arquivar resultados';
$zmSlangFilterDeleteEvents   = 'Apagar resultados';
$zmSlangFilterEmailEvents    = 'Enviar e-mail com detalhes dos resultados';
$zmSlangFilterExecuteEvents  = 'Executar comando p/ resultados';
$zmSlangFilterMessageEvents  = 'Enviar Mensagem dos resultados';
$zmSlangFilterPx             = 'Px de Filtro';
$zmSlangFilters              = 'Filters';
$zmSlangFilterUnset          = 'You must specify a filter width and height';
$zmSlangFilterUploadEvents   = 'Fazer upload dos resultados';
$zmSlangFilterVideoEvents    = 'Create video for all matches';
$zmSlangFirst                = 'Primeiro';
$zmSlangFlippedHori          = 'Flipped Horizontally';
$zmSlangFlippedVert          = 'Flipped Vertically';
$zmSlangFocus                = 'Focus';
$zmSlangForceAlarm           = 'Forar Alarme';
$zmSlangFormat               = 'Format';
$zmSlangFPS                  = 'fps';
$zmSlangFPSReportInterval    = 'Intervalo de mostragem FPS';
$zmSlangFrameId              = 'Id de Imagem';
$zmSlangFrame                = 'Imagem';
$zmSlangFrameRate            = 'Velocidade de Imagem';
$zmSlangFrames               = 'Imagens';
$zmSlangFrameSkip            = 'Salto de Imagem';
$zmSlangFTP                  = 'FTP';
$zmSlangFunc                 = 'Func';
$zmSlangFunction             = 'Funo';
$zmSlangGain                 = 'Gain';
$zmSlangGeneral              = 'General';
$zmSlangGenerateVideo        = 'Gerar Video';
$zmSlangGeneratingVideo      = 'Gerando Video';
$zmSlangGoToZoneMinder       = 'Ir Para ZoneMinder.com';
$zmSlangGrey                 = 'Cinza';
$zmSlangGroup                = 'Group';
$zmSlangGroups               = 'Groups';
$zmSlangHasFocusSpeed        = 'Has Focus Speed';
$zmSlangHasGainSpeed         = 'Has Gain Speed';
$zmSlangHasHomePreset        = 'Has Home Preset';
$zmSlangHasIrisSpeed         = 'Has Iris Speed';
$zmSlangHasPanSpeed          = 'Has Pan Speed';
$zmSlangHasPresets           = 'Has Presets';
$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
$zmSlangHasTurboPan          = 'Has Turbo Pan';
$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
$zmSlangHigh                 = 'Alto';
$zmSlangHighBW               = 'Alta&nbsp;L/B';
$zmSlangHome                 = 'Home';
$zmSlangHour                 = 'Hora';
$zmSlangHue                  = 'Saturao';
$zmSlangId                   = 'Id';
$zmSlangIdle                 = 'Parado';
$zmSlangIgnore               = 'Ignorar';
$zmSlangImageBufferSize      = 'Tamanho de Buffer (imagens)';
$zmSlangImage                = 'Imagem';
$zmSlangImages               = 'Images';
$zmSlangInclude              = 'Incluir';
$zmSlangIn                   = 'In';
$zmSlangInverted             = 'Invertido';
$zmSlangIris                 = 'Iris';
$zmSlangKeyString            = 'Key String';
$zmSlangLabel                = 'Label';
$zmSlangLanguage             = 'Linguagem';
$zmSlangLast                 = 'ltimo';
$zmSlangLimitResultsPost     = 'resultados somente;'; // This is used at the end of the phrase 'Limit to first N results only'
$zmSlangLimitResultsPre      = 'Limitar aos primeiros'; // This is used at the beginning of the phrase 'Limit to first N results only'
$zmSlangLinkedMonitors       = 'Linked Monitors';
$zmSlangList                 = 'List';
$zmSlangLoad                 = 'Carga';
$zmSlangLocal                = 'Local';
$zmSlangLoggedInAs           = 'Conectado como';
$zmSlangLoggingIn            = 'Conectando';
$zmSlangLogin                = 'Conectar';
$zmSlangLogout               = 'Sair';
$zmSlangLow                  = 'Baixa';
$zmSlangLowBW                = 'Baixa&nbsp;L/B';
$zmSlangMain                 = 'Main';
$zmSlangMan                  = 'Man';
$zmSlangManual               = 'Manual';
$zmSlangMark                 = 'Marcar';
$zmSlangMaxBandwidth         = 'Max Bandwidth';
$zmSlangMaxBrScore           = 'Max.<br/>Score';
$zmSlangMaxFocusRange        = 'Max Focus Range';
$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
$zmSlangMaxFocusStep         = 'Max Focus Step';
$zmSlangMaxGainRange         = 'Max Gain Range';
$zmSlangMaxGainSpeed         = 'Max Gain Speed';
$zmSlangMaxGainStep          = 'Max Gain Step';
$zmSlangMaximumFPS           = 'Maximo FPS';
$zmSlangMaxIrisRange         = 'Max Iris Range';
$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
$zmSlangMaxIrisStep          = 'Max Iris Step';
$zmSlangMax                  = 'Maximo';
$zmSlangMaxPanRange          = 'Max Pan Range';
$zmSlangMaxPanSpeed          = 'Max Pan Speed';
$zmSlangMaxPanStep           = 'Max Pan Step';
$zmSlangMaxTiltRange         = 'Max Tilt Range';
$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
$zmSlangMaxTiltStep          = 'Max Tilt Step';
$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
$zmSlangMaxZoomRange         = 'Max Zoom Range';
$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
$zmSlangMaxZoomStep          = 'Max Zoom Step';
$zmSlangMediumBW             = 'Media&nbsp;L/B';
$zmSlangMedium               = 'Media';
$zmSlangMinAlarmAreaLtMax    = 'Minimum alarm area should be less than maximum';
$zmSlangMinAlarmAreaUnset    = 'You must specify the minimum alarm pixel count';
$zmSlangMinBlobAreaLtMax     = 'A area minima de blob deve ser menor do que a area mxima de blob';
$zmSlangMinBlobAreaUnset     = 'You must specify the minimum blob pixel count';
$zmSlangMinBlobLtMinFilter   = 'Minimum blob area should be less than or equal to minimum filter area';
$zmSlangMinBlobsLtMax        = 'O minimo de Blobs deve ser menor que o maximo de blobs';
$zmSlangMinBlobsUnset        = 'You must specify the minimum blob count';
$zmSlangMinFilterAreaLtMax   = 'Minimum filter area should be less than maximum';
$zmSlangMinFilterAreaUnset   = 'You must specify the minimum filter pixel count';
$zmSlangMinFilterLtMinAlarm  = 'Minimum filter area should be less than or equal to minimum alarm area';
$zmSlangMinFocusRange        = 'Min Focus Range';
$zmSlangMinFocusSpeed        = 'Min Focus Speed';
$zmSlangMinFocusStep         = 'Min Focus Step';
$zmSlangMinGainRange         = 'Min Gain Range';
$zmSlangMinGainSpeed         = 'Min Gain Speed';
$zmSlangMinGainStep          = 'Min Gain Step';
$zmSlangMinIrisRange         = 'Min Iris Range';
$zmSlangMinIrisSpeed         = 'Min Iris Speed';
$zmSlangMinIrisStep          = 'Min Iris Step';
$zmSlangMinPanRange          = 'Min Pan Range';
$zmSlangMinPanSpeed          = 'Min Pan Speed';
$zmSlangMinPanStep           = 'Min Pan Step';
$zmSlangMinPixelThresLtMax   = 'Minimum pixel threshold should be less than maximum';
$zmSlangMinPixelThresUnset   = 'You must specify a minimum pixel threshold';
$zmSlangMinTiltRange         = 'Min Tilt Range';
$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
$zmSlangMinTiltStep          = 'Min Tilt Step';
$zmSlangMinWhiteRange        = 'Min White Bal. Range';
$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
$zmSlangMinWhiteStep         = 'Min White Bal. Step';
$zmSlangMinZoomRange         = 'Min Zoom Range';
$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
$zmSlangMinZoomStep          = 'Min Zoom Step';
$zmSlangMisc                 = 'Misc';
$zmSlangMonitorIds           = 'Ids&nbsp;de Monitor';
$zmSlangMonitor              = 'Monitor';
$zmSlangMonitorPresetIntro   = 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>';
$zmSlangMonitorPreset        = 'Monitor Preset';
$zmSlangMonitors             = 'Monitores';
$zmSlangMontage              = 'Montagem';
$zmSlangMonth                = 'Ms';
$zmSlangMove                 = 'Move';
$zmSlangMustBeGe             = 'deve ser maior ou igual a';
$zmSlangMustBeLe             = 'deve ser menor ou igual a';
$zmSlangMustConfirmPassword  = 'Voce deve Confirmar a senha';
$zmSlangMustSupplyPassword   = 'Voce deve informar a senha';
$zmSlangMustSupplyUsername   = 'Voce deve informar nome de usurio';
$zmSlangName                 = 'Nome';
$zmSlangNear                 = 'Near';
$zmSlangNetwork              = 'Rede';
$zmSlangNewGroup             = 'New Group';
$zmSlangNewLabel             = 'New Label';
$zmSlangNew                  = 'Novo';
$zmSlangNewPassword          = 'Nova Senha';
$zmSlangNewState             = 'Novo Estado';
$zmSlangNewUser              = 'Novo Usurio';
$zmSlangNext                 = 'Prx';
$zmSlangNoFramesRecorded     = 'No h imagens gravadas neste evento';
$zmSlangNoGroup              = 'No Group';
$zmSlangNoneAvailable        = 'Nada disponvel';
$zmSlangNone                 = 'Nada';
$zmSlangNo                   = 'No';
$zmSlangNormal               = 'Normal';
$zmSlangNoSavedFilters       = 'SemFiltrosSalvos';
$zmSlangNoStatisticsRecorded = 'No h estatsticas gravadas neste evento/imagem';
$zmSlangNotes                = 'Notes';
$zmSlangNumPresets           = 'Num Presets';
$zmSlangOff                  = 'Off';
$zmSlangOn                   = 'On';
$zmSlangOpen                 = 'Open';
$zmSlangOpEq                 = 'igual a';
$zmSlangOpGtEq               = 'maior que ou igual a';
$zmSlangOpGt                 = 'maior que';
$zmSlangOpIn                 = 'no set';
$zmSlangOpLtEq               = 'menor que ou igual a';
$zmSlangOpLt                 = 'menor que';
$zmSlangOpMatches            = 'combina';
$zmSlangOpNe                 = 'diferente de';
$zmSlangOpNotIn              = 'no no set';
$zmSlangOpNotMatches         = 'no combina';
$zmSlangOptionHelp           = 'OpoAjuda';
$zmSlangOptionRestartWarning = 'Reinicie o Zoneminder para que as mudanas tenham efeito';
$zmSlangOptions              = 'Opes';
$zmSlangOrder                = 'Order';
$zmSlangOrEnterNewName       = 'ou defina novo nome';
$zmSlangOrientation          = 'Orientao';
$zmSlangOut                  = 'Out';
$zmSlangOverwriteExisting    = 'Sobrescrever Existente';
$zmSlangPaged                = 'Paginado';
$zmSlangPanLeft              = 'Pan Left';
$zmSlangPan                  = 'Pan';
$zmSlangPanRight             = 'Pan Right';
$zmSlangPanTilt              = 'Pan/Tilt';
$zmSlangParameter            = 'Parametro';
$zmSlangPasswordsDifferent   = 'A nova senha e a de confirmao so diferentes';
$zmSlangPassword             = 'Senha';
$zmSlangPaths                = 'Caminhos';
$zmSlangPause                = 'Pause';
$zmSlangPhoneBW              = 'Discada&nbsp;L/B';
$zmSlangPhone                = 'Phone';
$zmSlangPixelDiff            = 'Pixel Diff';
$zmSlangPixels               = 'pixels';
$zmSlangPlayAll              = 'Play All';
$zmSlangPlay                 = 'Play';
$zmSlangPleaseWait           = 'Por Favor Espere';
$zmSlangPoint                = 'Point';
$zmSlangPostEventImageBuffer = 'Buffer de imagem ps evento';
$zmSlangPreEventImageBuffer  = 'Buffer de imagem pr evento';
$zmSlangPreserveAspect       = 'Preserve Aspect Ratio';
$zmSlangPreset               = 'Preset';
$zmSlangPresets              = 'Presets';
$zmSlangPrev                 = 'Ant.';
$zmSlangProtocol             = 'Protocol';
$zmSlangRate                 = 'Vel.';
$zmSlangReal                 = 'Real';
$zmSlangRecord               = 'Gravar';
$zmSlangRefImageBlendPct     = 'Referncia de imagem Blend %ge';
$zmSlangRefresh              = 'Atualizar';
$zmSlangRemoteHostName       = 'Nome do host remoto';
$zmSlangRemoteHostPath       = 'Caminho do host remoto';
$zmSlangRemoteHostPort       = 'Porta do host remoto';
$zmSlangRemoteImageColours   = 'Cores de imagem remota';
$zmSlangRemote               = 'Remoto';
$zmSlangRename               = 'Renomear';
$zmSlangReplayAll            = 'All Events';
$zmSlangReplayGapless        = 'Gapless Events';
$zmSlangReplay               = 'Replay';
$zmSlangReplaySingle         = 'Single Event';
$zmSlangReplay               = 'Ver Novamente';
$zmSlangResetEventCounts     = 'Resetar contagem de eventos';
$zmSlangReset                = 'Reset';
$zmSlangRestarting           = 'Reiniciando';
$zmSlangRestart              = 'Reiniciar';
$zmSlangRestrictedCameraIds  = 'Ids de camera proibdos';
$zmSlangRestrictedMonitors   = 'Restricted Monitors';
$zmSlangReturnDelay          = 'Return Delay';
$zmSlangReturnLocation       = 'Return Location';
$zmSlangRewind               = 'Rewind';
$zmSlangRotateLeft           = 'Rotacionar  esquerda ';
$zmSlangRotateRight          = 'Rotacionar  direita';
$zmSlangRunMode              = 'Modo de Execuo';
$zmSlangRunning              = 'Rodando';
$zmSlangRunState             = 'Estado de Execuo';
$zmSlangSaveAs               = 'Salvar Como';
$zmSlangSaveFilter           = 'Salvar Filtro';
$zmSlangSave                 = 'Salvar';
$zmSlangScale                = 'Tamanho';
$zmSlangScore                = 'Score';
$zmSlangSecs                 = 'Segs';
$zmSlangSectionlength        = 'Tamanho de evento Fixo';
$zmSlangSelectMonitors       = 'Select Monitors';
$zmSlangSelect               = 'Select';
$zmSlangSelfIntersecting     = 'Polygon edges must not intersect';
$zmSlangSetLearnPrefs        = 'Set Learn Prefs'; // This can be ignored for now
$zmSlangSetNewBandwidth      = 'Defina Nova L/B';
$zmSlangSetPreset            = 'Set Preset';
$zmSlangSet                  = 'Set';
$zmSlangSettings             = 'Configuraes';
$zmSlangShowFilterWindow     = 'MostrarJanelaDeFiltros';
$zmSlangShowTimeline         = 'Show Timeline';
$zmSlangSignalCheckColour    = 'Signal Check Colour';
$zmSlangSize                 = 'Size';
$zmSlangSleep                = 'Sleep';
$zmSlangSortAsc              = 'Asc';
$zmSlangSortBy               = 'mostrar por';
$zmSlangSortDesc             = 'Desc';
$zmSlangSource               = 'Origem';
$zmSlangSourceType           = 'Tipo de Origem';
$zmSlangSpeedHigh            = 'High Speed';
$zmSlangSpeedLow             = 'Low Speed';
$zmSlangSpeedMedium          = 'Medium Speed';
$zmSlangSpeed                = 'Speed';
$zmSlangSpeedTurbo           = 'Turbo Speed';
$zmSlangStart                = 'Iniciar';
$zmSlangState                = 'Estado';
$zmSlangStats                = 'Status';
$zmSlangStatus               = 'Status';
$zmSlangStepBack             = 'Step Back';
$zmSlangStepForward          = 'Step Forward';
$zmSlangStepLarge            = 'Large Step';
$zmSlangStepMedium           = 'Medium Step';
$zmSlangStepNone             = 'No Step';
$zmSlangStepSmall            = 'Small Step';
$zmSlangStep                 = 'Step';
$zmSlangStills               = 'Imagens';
$zmSlangStop                 = 'Parar';
$zmSlangStopped              = 'Parado';
$zmSlangStream               = 'Contnuo';
$zmSlangStreamReplayBuffer   = 'Stream Replay Image Buffer';
$zmSlangSubmit               = 'Submit';
$zmSlangSystem               = 'Sistema';
$zmSlangTele                 = 'Tele';
$zmSlangThumbnail            = 'Thumbnail';
$zmSlangTilt                 = 'Tilt';
$zmSlangTimeDelta            = 'Tempo Delta';
$zmSlangTimeline             = 'Timeline';
$zmSlangTimestampLabelFormat = 'Formato de etiqueta de tempo';
$zmSlangTimestampLabelX      = 'posio de etiqueta X';
$zmSlangTimestampLabelY      = 'posio de  etiqueta Y';
$zmSlangTimestamp            = 'Tempo';
$zmSlangTimeStamp            = 'Tempo';
$zmSlangTime                 = 'Tempo';
$zmSlangToday                = 'Today';
$zmSlangTools                = 'Ferramentas';
$zmSlangTotalBrScore         = 'Score<br/>Total';
$zmSlangTrackDelay           = 'Track Delay';
$zmSlangTrackMotion          = 'Track Motion';
$zmSlangTriggers             = 'Acionadores';
$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
$zmSlangType                 = 'Tipo';
$zmSlangUnarchive            = 'Desarquivar';
$zmSlangUnits                = 'Unidades';
$zmSlangUnknown              = 'Desconhecido';
$zmSlangUpdateAvailable      = 'Um update ao zoneminder est disponvel.';
$zmSlangUpdateNotNecessary   = 'No  necessrio update.';
$zmSlangUpdate               = 'Update';
$zmSlangUseFilterExprsPost   = '&nbsp;expresses&nbsp;de&nbsp;filtragem'; // This is used at the end of the phrase 'use N filter expressions'
$zmSlangUseFilterExprsPre    = 'Use&nbsp;'; // This is used at the beginning of the phrase 'use N filter expressions'
$zmSlangUseFilter            = 'Use Filtro';
$zmSlangUsername             = 'Nome de Usurio';
$zmSlangUsers                = 'Usurios';
$zmSlangUser                 = 'Usurio';
$zmSlangValue                = 'Valor';
$zmSlangVersionIgnore        = 'Ignorar esta verso';
$zmSlangVersionRemindDay     = 'Lembre novamente em 1 dia';
$zmSlangVersionRemindHour    = 'Lembre novamente em 1 hora';
$zmSlangVersionRemindNever   = 'Nao lembrar novas verses';
$zmSlangVersionRemindWeek    = 'Lembrar novamente em 1 semana';
$zmSlangVersion              = 'Verso';
$zmSlangVideoFormat          = 'Video Format';
$zmSlangVideoGenFailed       = 'Gerao de Vdeo falhou!';
$zmSlangVideoGenFiles        = 'Existing Video Files';
$zmSlangVideoGenNoFiles      = 'No Video Files Found';
$zmSlangVideoGenParms        = 'Parametros de  gerao de vdeo';
$zmSlangVideoGenSucceeded    = 'Video Generation Succeeded!';
$zmSlangVideoSize            = 'Tamanho do vdeo';
$zmSlangVideo                = 'Video';
$zmSlangViewAll              = 'Ver Tudo';
$zmSlangViewEvent            = 'View Event';
$zmSlangViewPaged            = 'Ver Paginado';
$zmSlangView                 = 'Ver';
$zmSlangWake                 = 'Wake';
$zmSlangWarmupFrames         = 'Imagens Desconsideradas';
$zmSlangWatch                = 'Assistir';
$zmSlangWebColour            = 'Web Colour';
$zmSlangWeb                  = 'Web';
$zmSlangWeek                 = 'Semana';
$zmSlangWhiteBalance         = 'White Balance';
$zmSlangWhite                = 'White';
$zmSlangWide                 = 'Wide';
$zmSlangX10ActivationString  = 'String de Ativao X10';
$zmSlangX10InputAlarmString  = 'String de Entrada  de alarme X10';
$zmSlangX10OutputAlarmString = 'String de Sada de Alarme X10';
$zmSlangX10                  = 'X10';
$zmSlangX                    = 'X';
$zmSlangYes                  = 'Sim';
$zmSlangYouNoPerms           = 'Voc no tem permisses para acessar este recurso.';
$zmSlangY                    = 'Y';
$zmSlangZoneAlarmColour      = 'Cor de Alarme (Red/Green/Blue)';
$zmSlangZoneArea             = 'Zone Area';
$zmSlangZoneFilterSize       = 'Filter Width/Height (pixels)';
$zmSlangZoneMinMaxAlarmArea  = 'Min/Max Alarmed Area';
$zmSlangZoneMinMaxBlobArea   = 'Min/Max Blob Area';
$zmSlangZoneMinMaxBlobs      = 'Min/Max Blobs';
$zmSlangZoneMinMaxFiltArea   = 'Min/Max Filtered Area';
$zmSlangZoneMinMaxPixelThres = 'Min/Max Pixel Threshold (0-255)';
$zmSlangZoneOverloadFrames   = 'Overload Frame Ignore Count';
$zmSlangZones                = 'Zonas';
$zmSlangZone                 = 'Zona';
$zmSlangZoomIn               = 'Zoom In';
$zmSlangZoomOut              = 'Zoom Out';
$zmSlangZoom                 = 'Zoom';

// Complex replacements with formatting and/or placements, must be passed through sprintf
$zmClangCurrentLogin         = 'Login atual  \'%1$s\'';
$zmClangEventCount           = '%1$s %2$s'; // For example '37 Events' (from Vlang below)
$zmClangLastEvents           = 'ltimos %1$s %2$s'; // For example 'Last 37 Events' (from Vlang below)
$zmClangLatestRelease        = 'A ltima verso  v%1$s, voc tem v%2$s.';
$zmClangMonitorCount         = '%1$s %2$s'; // For example '4 Monitors' (from Vlang below)
$zmClangMonitorFunction      = 'Monitor %1$s Funco';
$zmClangRunningRecentVer     = 'Voc est usando a verso mais recente do ZoneMinder, v%s.';

// The next section allows you to describe a series of word ending and counts used to 
// generate the correctly conjugated forms of words depending on a count that is associated
// with that word.
// This intended to allow phrases such a '0 potatoes', '1 potato', '2 potatoes' etc to
// conjugate correctly with the associated count.
// In some languages such as English this is fairly simple and can be expressed by assigning
// a count with a singular or plural form of a word and then finding the nearest (lower) value.
// So '0' of something generally ends in 's', 1 of something is singular and has no extra
// ending and 2 or more is a plural and ends in 's' also. So to find the ending for '187' of
// something you would find the nearest lower count (2) and use that ending.
//
// So examples of this would be
// $zmVlangPotato = array( 0=>'Potatoes', 1=>'Potato', 2=>'Potatoes' );
// $zmVlangSheep = array( 0=>'Sheep' );
//
// where you can have as few or as many entries in the array as necessary
// If your language is similar in form to this then use the same format and choose the
// appropriate zmVlang function below.
// If however you have a language with a different format of plural endings then another
// approach is required . For instance in Russian the word endings change continuously
// depending on the last digit (or digits) of the numerator. In this case then zmVlang
// arrays could be written so that the array index just represents an arbitrary 'type'
// and the zmVlang function does the calculation about which version is appropriate.
//
// So an example in Russian might be (using English words, and made up endings as I
// don't know any Russian!!)
// $zmVlangPotato = array( 1=>'Potati', 2=>'Potaton', 3=>'Potaten' );
//
// and the zmVlang function decides that the first form is used for counts ending in
// 0, 5-9 or 11-19 and the second form when ending in 1 etc.
//

// Variable arrays expressing plurality, see the zmVlang description above
$zmVlangEvent                = array( 0=>'Events', 1=>'Event', 2=>'Events' );
$zmVlangMonitor              = array( 0=>'Monitors', 1=>'Monitor', 2=>'Monitors' );

// You will need to choose or write a function that can correlate the plurality string arrays
// with variable counts. This is used to conjugate the Vlang arrays above with a number passed
// in to generate the correct noun form.
//
// In languages such as English this is fairly simple 
// Note this still has to be used with printf etc to get the right formating
function zmVlang( $lang_var_array, $count )
{
	krsort( $lang_var_array );
	foreach ( $lang_var_array as $key=>$value )
	{
		if ( abs($count) >= $key )
		{
			return( $value );
		}
	}
	die( 'Error, unable to correlate variable language string' );
}

// This is an version that could be used in the Russian example above
// The rules are that the first word form is used if the count ends in
// 0, 5-9 or 11-19. The second form is used then the count ends in 1
// (not including 11 as above) and the third form is used when the 
// count ends in 2-4, again excluding any values ending in 12-14.
// 
// function zmVlang( $lang_var_array, $count )
// {
// 	$secondlastdigit = substr( $count, -2, 1 );
// 	$lastdigit = substr( $count, -1, 1 );
// 	// or
// 	// $secondlastdigit = ($count/10)%10;
// 	// $lastdigit = $count%10;
// 
// 	// Get rid of the special cases first, the teens
// 	if ( $secondlastdigit == 1 && $lastdigit != 0 )
// 	{
// 		return( $lang_var_array[1] );
// 	}
// 	switch ( $lastdigit )
// 	{
// 		case 0 :
// 		case 5 :
// 		case 6 :
// 		case 7 :
// 		case 8 :
// 		case 9 :
// 		{
// 			return( $lang_var_array[1] );
// 			break;
// 		}
// 		case 1 :
// 		{
// 			return( $lang_var_array[2] );
// 			break;
// 		}
// 		case 2 :
// 		case 3 :
// 		case 4 :
// 		{
// 			return( $lang_var_array[3] );
// 			break;
// 		}
// 	}
// 	die( 'Error, unable to correlate variable language string' );
// }

// This is an example of how the function is used in the code which you can uncomment and 
// use to test your custom function.
//$monitors = array();
//$monitors[] = 1; // Choose any number
//echo sprintf( $zmClangMonitorCount, count($monitors), zmVlang( $zmVlangMonitor, count($monitors) ) );

// In this section you can override the default prompt and help texts for the options area
// These overrides are in the form of $zmOlangPrompt<option> and $zmOlangHelp<option>
// where <option> represents the option name minus the initial ZM_
// So for example, to override the help text for ZM_LANG_DEFAULT do
//$zmOlangPromptLANG_DEFAULT = "This is a new prompt for this option";
//$zmOlangHelpLANG_DEFAULT = "This is some new help for this option which will be displayed in the popup window when the ? is clicked";
//

?>
